---
title: Configuration
type: docs
summary: Configuration via `modo.yaml` and CLI flags.
weight: 2
---
Modo🧯 can run based on a [config file](#config-file) or [standalone](#standalone).

## Config file

A Modo🧯 project is defined by a file `modo.yaml`.
This file contains the complete configuration for commands `build` and `test`.
A config file can be generated with the `init` command:

```{class="no-wrap"}
modo init
```

The content of the generated file is shown [at the bottom](#config-file-reference) of this page.

When `modo build` or `modo test` are executed in a folder containing a `modo.yaml`,
the file is used for configuration and no command like flags are required:

```{class="no-wrap"}
modo build
```

However, command line flags can still be used to overwrite the values that were read from the file.
As an example, this is how to overwrite the output format:

```{class="no-wrap"}
modo build --format=hugo
```

All config file entries are also exposed as command line flags,
except for pre- and post-commands (`pre-run`, `pre-build`, ...).

## Standalone

Modo🧯 can also be used without a `modo.yaml` config file.
If there is no such file in the current directory,
an empty configuration is used.
Command line flags must be used for any configuration:

```{class="no-wrap"}
modo build -i api.json -o docs/
```

## Config file reference

The code listing below shows the content of `modo.yaml` as produced by `modo init`.

All **paths are relative** to the location of the file.

```yaml {class="no-wrap" filename="modo.yaml"}
# Input files as generated by `mojo doc`.
# If a single directory is given, it is processed recursively.
input:
  - api.json

# Output directory.
output: docs/

# Output directory for doc-tests.
# Remove or set to "" to disable doc-tests.
tests: doctest/

# Output format. One of (plain|hugo|mdbook).
format: plain

# Re-structure docs according to package re-exports.
exports: true

# Use shortened cross-ref link labels.
short-links: true

# Break with error on any warning.
strict: false

# Run without generating any output files.
dry-run: false

# Build for systems that are not case-sensitive regarding file names.
# Appends hyphen (-) to capitalized file names.
case-insensitive: false

# Directories to scan for templates to overwrite builtin templates.
templates: []

# Bash commands to run before build as well as test.
pre-run:
  - |
    echo You can use pre- and post-commands...
    echo to run 'mojo doc', 'mojo test', etc.

# Bash scripts to run before build.
pre-build: []

# Bash scripts to run before test.
# Also runs before build if 'tests' is given.
pre-test: []

# Bash scripts to run after test.
# Also runs after build if 'tests' is given.
post-test: []

# Bash scripts to run after build.
post-build: []

# Bash scripts to run after build as well as test.
post-run: []
```